@@ -50,7 +50,7 @@ The column headers for the output include sample name, time to run, and
 corrected and uncorrected dates at a minimum. If linear uncertainty
 propagation is requested, 1-s uncertainty columns are added.
 If Monte Carlo uncertainty propagation is requested, +/- 68% confidence
-intervals are added along with % skew.
+intervals are added.
 '''
 
 import pandas as pd
@@ -71,13 +71,11 @@ def _get_cols(linear, monteCarlo, parameterize):
                     'Linear raw uncertainty',
                     ' +68% CI raw',
                     ' -68% CI raw',
-                    '% Skewness of raw distribution',
                     'Corrected date',
                     'Mean corrected date',
                     'Linear corrected uncertainty',
                     ' +68% CI corrected',
                     ' -68% CI corrected',
-                    '% Skewness of corrected distribution',
                     'Number of Monte Carlo simulations']
     if monteCarlo and not linear:
         save_columns = ['Sample',
@@ -85,12 +83,10 @@ def _get_cols(linear, monteCarlo, parameterize):
                         'Mean raw date',
                         ' +68% CI raw',
                         ' -68% CI raw',
-                        '% Skewness of raw distribution',
                         'Corrected date',
                         'Mean corrected date',
                         ' +68% CI corrected',
                         ' -68% CI corrected',
-                        '% Skewness of corrected distribution',
                         'Number of Monte Carlo simulations']
     elif linear and not monteCarlo:
         save_columns = ['Sample',
@@ -105,10 +101,10 @@ def _get_cols(linear, monteCarlo, parameterize):
     # If parameterization is chosen, add the relevant columns
     # at the end of the raw and corrected data output
     if parameterize:
-        ins_idx = save_columns.index('% Skewness of raw distribution')
+        ins_idx = save_columns.index(' -68% CI raw')
         add_cols = ['raw fit a','raw fit u','raw fit s']
         save_columns = save_columns[:ins_idx+1]+add_cols+save_columns[ins_idx+1:]
-        ins_idx = save_columns.index('% Skewness of corrected distribution')
+        ins_idx = save_columns.index(' -68% CI corrected')
         add_cols = ['corrected fit a','corrected fit u','corrected fit s']
         save_columns = save_columns[:ins_idx+1]+add_cols+save_columns[ins_idx+1:]
     return save_columns
@@ -247,8 +243,6 @@ def _make_excel(save_out, save_columns, file, monteCarlo, precision_user, saveAs
     for cell in output[colHead_row]:
         cell.font = styles.Font(bold=True)
         cell.alignment = styles.Alignment(wrapText=True)
-        if '% Skewness' in cell.value:
-            output.column_dimensions[utils.get_column_letter(cell.column)].width = 20
         if 'Linear' in cell.value:
             output.column_dimensions[utils.get_column_letter(cell.column)].width = 15
         if 'Corrected date' in cell.value:
@@ -327,9 +321,13 @@ def _sample_loop(save_out, sample_data, measured_U235, linear, monteCarlo,
         save_out['Linear raw uncertainty'].append(round(linear_uncertainty['raw unc']/1e6,decimals))
         save_out['Linear corrected uncertainty'].append(round(linear_uncertainty['corr unc']/1e6,decimals))
     
+    #TODO set that If data don't result in valid date, skip Monte Carlo simulation
+    # if any(np.isnan(save_out[n] for n in save_out)):
+    #     monteCarlo = False
+    
     if monteCarlo:
         # Estimate the number of cycles needed to reach the requested precision
-        s_est = linear_uncertainty['raw unc']
+        s_est = linear_uncertainty['corr unc']
         mean_est = nominal_t['corrected date']
         mc_number = s_est**2/(precision*mean_est)**2
         if mc_number < 5:
@@ -347,6 +345,8 @@ def _sample_loop(save_out, sample_data, measured_U235, linear, monteCarlo,
             U235_s = sample_data[u'\u00B1 235U']
         
         # Call the monte carlo module
+        #TODO recognize if the monte carlo has too many samples removed for precision level
+        #TODO recognize nans in mc results and handle accordingly
         mc_results = monte_carlo(
             mc_number, sample_data['4He'], sample_data[u'\u00B1 4He'],
             sample_data['238U'], U235, sample_data['232Th'], sample_data['147Sm'],
@@ -357,13 +357,12 @@ def _sample_loop(save_out, sample_data, measured_U235, linear, monteCarlo,
             sample_data[u'\u00B1 232Ft'], sample_data[u'\u00B1 147Ft'],
             histogram=histograms, parameterize=parameterize
             )
-        
+                
         # Put Monte Carlo results into data framework for saving
         for ft in ['raw', 'corrected']:
             save_out['Mean '+ft+' date'].append(round(mc_results[ft+' date']['mean']/1e6,decimals))
             save_out[' +68% CI '+ft].append(round(mc_results[ft+' date']['+68% CI']/1e6,decimals))
             save_out[' -68% CI '+ft].append(round(mc_results[ft+' date']['-68% CI']/1e6,decimals))
-            save_out['% Skewness of '+ft+' distribution'].append(round(mc_results[ft+' date']['% Skew'],decimals))
             if histograms:
                 mc_results[ft+' date']['histogram'][0] = np.around(mc_results[ft+' date']['histogram'][0]/1e6,decimals)
                 mc_results[ft+' date']['histogram'][1] = mc_results[ft+' date']['histogram'][1]
@@ -444,11 +443,10 @@ def hecalc_main(file=None, saveAs=None, percent_precision=0.01, decimals=5, meas
     For all calculations, the sample name and date are returned
     If linear is chosen, the 1-sigma uncertainty is included
     If montecarlo is chosen, the 68% confidence intervals, mean date,
-    skewness (as a percent difference between the confidence intervals),
     and number of cycles necessary to reach the requested precision.
     If parameterization was requested, the fitted parameters a, u, and s
-    are included with a being skewness, u the location parameter, and
-    s the shape parameter for a Skew-normal function.
+    are included with a being shape, u the location parameter, and
+    s the scale parameter for a Skew-normal function.
     If histograms are produced, these will be saved in a second excel
     sheet with the both the raw and corrected histograms given with
     bin centers (in units of Ma) and the absolute number of Monte Carlo
@@ -509,7 +507,7 @@ def hecalc_main(file=None, saveAs=None, percent_precision=0.01, decimals=5, meas
             data['Sample'].iloc[i] = re.sub('[^\w\-_]', '_', data['Sample'].iloc[i])
         
         # Get the individual sample data as a dictionary
-        sample_data = data.loc[[i]].to_dict(orient='record')[0]
+        sample_data = data.loc[[i]].to_dict(orient='records')[0]
         
         save_out = _sample_loop(save_out, sample_data, measured_U235, linear, monteCarlo,
                                 histograms, parameterize, decimals, precision)
